ml package
==========

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   ml.evaluation
   ml.images
   ml.neuralnetworks
   ml.timeseries

Submodules
----------

ml.dataframes module
--------------------

.. automodule:: ml.dataframes
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: ml
   :members:
   :undoc-members:
   :show-inheritance:
